==> amis-1.0.12-beta.3.tgz: package/src/components/index.tsx <==
/**
 * @file Index
 * @description
 * @author fex
 */

import NotFound from './404';
import {default as Alert, alert, confirm} from './Alert';
import {default as ContextMenu, openContextMenus} from './ContextMenu';
import AsideNav from './AsideNav';
import Button from './Button';
import Checkbox from './Checkbox';
import Checkboxes from './Checkboxes';
import Collapse from './Collapse';
import ColorPicker from './ColorPicker';
import DatePicker from './DatePicker';
import DateRangePicker from './DateRangePicker';
import Drawer from './Drawer';
import {default as Tabs, Tab} from './Tabs';
import Editor from './Editor';
import Html from './Html';
import * as Icons from './icons';
import Layout from './Layout';
import LazyComponent from './LazyComponent';
import Modal from './Modal';
import Overlay from './Overlay';
import PopOver from './PopOver';
import Radios from './Radios';
import Range from './Range';
import Rating from './Rating';
// import RichText from './RichText';
import Select from './Select';
import Spinner from './Spinner';
import Switch from './Switch';
import Textarea from './Textarea';
import TitleBar from './TitleBar';
import {default as ToastComponent, toast} from './Toast';
import Tooltip from './Tooltip';
import TooltipWrapper from './TooltipWrapper';
import Tree from './Tree';
import Alert2 from './Alert2';
import Transfer from './Transfer';
import TabsTransfer from './TabsTransfer';
import ListCheckboxes from './ListCheckboxes';
import TableCheckboxes from './TableCheckboxes';
import TreeCheckboxes from './TreeCheckboxes';
import ChainedCheckboxes from './ChainedCheckboxes';
import ResultBox from './ResultBox';
import InputBox from './InputBox';
import ListRadios from './ListRadios';
import TreeRadios from './TreeRadios';

export {
  NotFound,
  Alert as AlertComponent,
  alert,
  ContextMenu,
  openContextMenus,
  Alert2,
  confirm,
  AsideNav,
  Button,
  Checkbox,
  Checkboxes,
  Collapse,
  ColorPicker,
  DatePicker,
  DateRangePicker,
  Drawer,
  Tabs,
  Tab,
  Editor,
  Html,
  Icons,
  Layout,
  LazyComponent,
  Modal,
  Overlay,
  PopOver,
  Radios,
  Range,
  Rating,
  // RichText,
  Select,
  Spinner,
  Switch,
  Textarea,
  TitleBar,
  ToastComponent,
  toast,
  Tooltip,
  TooltipWrapper,
  Tree,
  Transfer,
  TabsTransfer,
  ListCheckboxes,
  TableCheckboxes,
  TreeCheckboxes,
  ChainedCheckboxes,
  ResultBox,
  InputBox,
  ListRadios,
  TreeRadios
};

==> amis-1.8.0-beta.3.tgz: package/src/components/index.tsx <==
/**
 * @file Index
 * @description
 * @author fex
 */

import NotFound from './404';
import {default as Alert, alert, confirm, prompt} from './Alert';
import {default as ContextMenu, openContextMenus} from './ContextMenu';
import AsideNav from './AsideNav';
import Avatar from './Avatar';
import Button from './Button';
import Breadcrumb from './Breadcrumb';
import Checkbox from './Checkbox';
import Checkboxes from './Selection';
import Collapse from './Collapse';
import CollapseGroup from './CollapseGroup';
import DatePicker from './DatePicker';
import DateRangePicker from './DateRangePicker';
import Drawer from './Drawer';
import {default as Tabs, Tab} from './Tabs';
import Editor from './Editor';
import Html from './Html';
import * as Icons from './icons';
import Layout from './Layout';
import LazyComponent from './LazyComponent';
import Modal from './Modal';
import Overlay from './Overlay';
import PopOver from './PopOver';
import Radios from './Radios';
import Range from './Range';
import Rating from './Rating';
// import RichText from './RichText';
import Select from './Select';
import SparkLine from './SparkLine';
import Spinner from './Spinner';
import Switch from './Switch';
import Textarea from './Textarea';
import TitleBar from './TitleBar';
import {default as ToastComponent, toast} from './Toast';
import Tooltip from './Tooltip';
import TooltipWrapper from './TooltipWrapper';
import Tree from './Tree';
import Alert2 from './Alert2';
import Transfer from './Transfer';
import TabsTransfer from './TabsTransfer';
import ResultBox from './ResultBox';
import InputBox from './InputBox';
import ListGroup from './ListGroup';
import NumberInput from './NumberInput';
import ArrayInput from './ArrayInput';
import SearchBox from './SearchBox';
import AnchorNav from './AnchorNav';
import Selection from './Selection';
import GroupedSelection from './GroupedSelection';
import ChainedSelection from './ChainedSelection';
import TableSelection from './TableSelection';
import TreeSelection from './TreeSelection';
import AssociatedSelection from './AssociatedSelection';

export {
  NotFound,
  Alert as AlertComponent,
  alert,
  Avatar,
  confirm,
  prompt,
  ContextMenu,
  openContextMenus,
  Alert2,
  AsideNav,
  Button,
  Breadcrumb,
  Checkbox,
  Checkboxes,
  Collapse,
  CollapseGroup,
  DatePicker,
  DateRangePicker,
  Drawer,
  Tabs,
  Tab,
  Editor,
  Html,
  Icons,
  Layout,
  LazyComponent,
  Modal,
  Overlay,
  PopOver,
  Radios,
  Range,
  Rating,
  // RichText,
  Select,
  SparkLine,
  Spinner,
  Switch,
  Textarea,
  TitleBar,
  ToastComponent,
  toast,
  Tooltip,
  TooltipWrapper,
  Tree,
  Transfer,
  TabsTransfer,
  Selection,
  GroupedSelection,
  ChainedSelection,
  TableSelection,
  TreeSelection,
  AssociatedSelection,
  ResultBox,
  InputBox,
  SearchBox,
  ListGroup,
  NumberInput,
  ArrayInput,
  AnchorNav
};
